@@ -1,16 +1,17 @@
 package Foo;
 
+use strict;
 use Sub::Private;
 
-sub foo { 
-    return 42
+sub foo {
+    return 42;
 }
 
-sub bar :Private { 
+sub bar :Private {
     return foo() + 1;
 }
 
-sub baz { 
+sub baz {
     return bar() + 1;
 }
 
